==> hypre_2.0.0.dfsg.orig.tar.gz: hypre-2.0.0.dfsg/src/FEI_mv/fei-hypre/HYPRE_FEI_includes.h <==
/*BHEADER**********************************************************************
 * Copyright (c) 2006   The Regents of the University of California.
 * Produced at the Lawrence Livermore National Laboratory.
 * Written by the HYPRE team. UCRL-CODE-222953.
 * All rights reserved.
 *
 * This file is part of HYPRE (see http://www.llnl.gov/CASC/hypre/).
 * Please see the COPYRIGHT_and_LICENSE file for the copyright notice, 
 * disclaimer, contact information and the GNU Lesser General Public License.
 *
 * HYPRE is free software; you can redistribute it and/or modify it under the 
 * terms of the GNU General Public License (as published by the Free Software
 * Foundation) version 2.1 dated February 1999.
 *
 * HYPRE is distributed in the hope that it will be useful, but WITHOUT ANY 
 * WARRANTY; without even the IMPLIED WARRANTY OF MERCHANTABILITY or FITNESS 
 * FOR A PARTICULAR PURPOSE.  See the terms and conditions of the GNU General
 * Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 * $Revision: 2.6 $
 ***********************************************************************EHEADER*/




// *************************************************************************
// Different definitions for FEI and NOFEI options
// *************************************************************************

#ifndef __HYPRE_FEI_INCLUDES__
#define __HYPRE_FEI_INCLUDES__

#ifndef NOFEI

#include "fei_defs.h"
#include "base/Data.h"
#include "base/Lookup.h"
#include "base/LinearSystemCore.h"

#else

#define GlobalID int
class Lookup { 
public:
   Lookup() {}
   ~Lookup() {}
   int  getNumFields() {return -1;}
   int  getFieldSize(int) {return -1;}
   int* getFieldIDsPtr() {return NULL;}
   int* getFieldSizesPtr() {return NULL;}
   int  getNumElemBlocks() {return -1;}
   int* getElemBlockIDs() {return NULL;}
   void getElemBlockInfo(int,int&,int&,int&,int&,int&,int&){return;}
   int *getNumFieldsPerNode(int) {return NULL;}
   int**getFieldIDsTable(int) {return NULL;}
   int  getEqnNumber(int, int) {return -1;}
   int  getAssociatedNodeNumber(int) {return -1;}
   int  getAssociatedFieldID(int) {return -1;}
   int  isInLocalElement(int) {return -1;}
   int  getNumSubdomains(int) {return -1;}
   int *getSubdomainList(int) {return NULL;}
   int  getNumSharedNodes() {return -1;}
   int *getSharedNodeNumbers() {return NULL;}
   int *getSharedNodeProcs(int) {return NULL;}
   int  getNumSharingProcs(int) {return -1;}
   int  isExactlyBlkEqn(int) {return -1;}
   int  ptEqnToBlkEqn(int) {return -1;}
   int  getOffsetIntoBlkEqn(int, int) {return -1;}
   int  getBlkEqnSize(int) {return -1;}
};

#endif

#endif

==> hypre_2.11.1.orig.tar.gz: hypre-2.11.1/src/FEI_mv/fei-hypre/HYPRE_FEI_includes.h <==
/*BHEADER**********************************************************************
 * Copyright (c) 2008,  Lawrence Livermore National Security, LLC.
 * Produced at the Lawrence Livermore National Laboratory.
 * This file is part of HYPRE.  See file COPYRIGHT for details.
 *
 * HYPRE is free software; you can redistribute it and/or modify it under the
 * terms of the GNU Lesser General Public License (as published by the Free
 * Software Foundation) version 2.1 dated February 1999.
 *
 * $Revision$
 ***********************************************************************EHEADER*/





// *************************************************************************
// Different definitions for FEI and NOFEI options
// *************************************************************************

#ifndef __HYPRE_FEI_INCLUDES__
#define __HYPRE_FEI_INCLUDES__

#ifndef NOFEI

//New FEI 2.23.02
#include "fei_defs.h"
#include "fei_Data.hpp"
#include "fei_Lookup.hpp"
#include "fei_LinearSystemCore.hpp"

#else

#define GlobalID int
class Lookup { 
public:
   Lookup() {}
   ~Lookup() {}
   int  getNumFields() {return -1;}
   int  getFieldSize(int) {return -1;}
   int* getFieldIDsPtr() {return NULL;}
   int* getFieldSizesPtr() {return NULL;}
   int  getNumElemBlocks() {return -1;}
   int* getElemBlockIDs() {return NULL;}
   void getElemBlockInfo(int,int&,int&,int&,int&,int&,int&){return;}
   int *getNumFieldsPerNode(int) {return NULL;}
   int**getFieldIDsTable(int) {return NULL;}
   int  getEqnNumber(int, int) {return -1;}
   int  getAssociatedNodeNumber(int) {return -1;}
   int  getAssociatedFieldID(int) {return -1;}
   int  isInLocalElement(int) {return -1;}
   int  getNumSubdomains(int) {return -1;}
   int *getSubdomainList(int) {return NULL;}
   int  getNumSharedNodes() {return -1;}
   int *getSharedNodeNumbers() {return NULL;}
   int *getSharedNodeProcs(int) {return NULL;}
   int  getNumSharingProcs(int) {return -1;}
   int  isExactlyBlkEqn(int) {return -1;}
   int  ptEqnToBlkEqn(int) {return -1;}
   int  getOffsetIntoBlkEqn(int, int) {return -1;}
   int  getBlkEqnSize(int) {return -1;}
};

#endif

#endif
